# Translator.py - code for the Translator product
#
# Copyright (C) 2000 J. David Ibez, Andres Marzal <al028823@alumail.uji.es>
# Copyright (C) 2000 Federico Di Gregorio  <fog@mixadlive.com>
# Copyright (C) 2000 MIXAD LIVE S.r.l.  [http://www.mixadlive.com]
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTIBILITY
# or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
# for more details.
#
# -*- Mode: pyhton -*-

__doc__ = """Translator"""
__version__ = '0.5'
__author__ = """J. David Ibez <al028823@alumail.uji.es>
                Federico Di Gregorio <fog@mixadlive.com>"""


import sys, string, types
from string import split, strip, join

# zope specific imports
import Globals
from Globals import HTML 
from DocumentTemplate.DT_Util import *


class LocalizeTag:
    """dtml-localize implementation."""
    
    name = 'localize'
    blockContinuations = ()
    
    def __init__(self, blocks):
        """Initialization code."""
        tname, args, section = blocks[0]
        self.section = section.blocks
        if args[:9] == 'localize ': args = args[9:]
        args = parse_params(args, name='', expr='')
        self.args = args
        name, expr = name_param(args, 'localize', 1)
        self.__name__, self.expr = name, expr
        
    def render(self, md):
        """Render the content by looking for a translator."""
        if self.expr: val = self.expr.eval(md)
        else: val = self.__name__
        translator = md.getitem('translator', 0)
        try:
            v = translator(val)
            return render(md, v)
        except AttributeError:
            pass
        
        # not found, lets use the default
        ns = namespace(self)[0]
        md._push(InstanceDict(ns, md))
        try:
            s = render_blocks(self.section, md)
        finally:
            md._pop(1)
        try:
            return s
        except:
            raise AttributeError(val)

    # this make the tag to render (localize) on call
    __call__ = render


class LVarTag:
    """dtml-lvar implementation."""
    
    name = 'lvar'
    
    def __init__(self, args):
        """Initialization code."""
        if args[:5] == 'lvar ': args = args[5:]
        args = parse_params(args, name='', expr='', url=1)
        self.args = args
        name, expr = name_param(args, 'lvar', 1)
        self.__name__, self.expr = name, expr
        
    def render(self, md):
        """Render the content by looking for a translator."""
        if self.expr: val = self.expr.eval(md)
        else: val = self.__name__
        have_arg = self.args.has_key
        translator = md.getitem('translator', 0)
        try:
            v = translator(val)
            if have_arg('url'):
                return v.absolute_url()
            else:
                return str(render(md, v))
        except AttributeError:
            pass
        raise AttributeError(val)

    # this make the tag to render (localize) on call
    __call__ = render


